@@ -45,9 +45,9 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/release"
-	helmoperator "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/release"
+	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	"github.com/stolostron/multicloud-operators-subscription-release/pkg/release"
+	helmoperator "github.com/stolostron/multicloud-operators-subscription-release/pkg/release"
 )
 
 const (
