@@ -92,6 +92,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -189,6 +190,11 @@ func TestReconcile(t *testing.T) {
 	g.Expect(len(instanceResp.Status.Conditions)).To(gomega.Equal(2))
 	g.Expect(instanceResp.Status.Conditions[1].Reason).To(gomega.Equal(appv1.ReasonUpgradeSuccessful))
 
+	instanceResp.Repo.Source.GitHub.Urls[0] = "https://github.com/stolostron/multicloud-operators-subscription-release-wrongurl.git"
+
+	err = c.Delete(context.TODO(), instanceResp)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
 	//
 	//Github failed
 	//
@@ -214,6 +220,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "wrong path",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -256,6 +263,7 @@ func TestReconcile(t *testing.T) {
 				Git: &appv1.Git{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "wrong path",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -297,7 +305,7 @@ func TestReconcile(t *testing.T) {
 				SourceType: appv1.HelmRepoSourceType,
 				HelmRepo: &appv1.HelmRepo{
 					Urls: []string{
-						"https://raw.github.com/stolostron/multicloud-operators-subscription-release/master/test/helmrepo/subscription-release-test-3-0.1.0.tgz"},
+						"https://raw.github.com/stolostron/multicloud-operators-subscription-release/main/test/helmrepo/subscription-release-test-3-0.1.0.tgz"},
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -333,6 +341,11 @@ func TestReconcile(t *testing.T) {
 	g.Expect(instanceResp.Status.DeployedRelease).NotTo(gomega.BeNil())
 	g.Expect(instanceResp.Repo.Version).Should(gomega.Equal("3-0.1.0"))
 
+	instanceResp.Repo.Source.HelmRepo.Urls[0] = "https://github.com/stolostron/multicloud-operators-subscription-release-wrongurl"
+
+	err = c.Delete(context.TODO(), instanceResp)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
 	//
 	//helmRepo failure
 	//
@@ -399,6 +412,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -456,6 +470,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -522,6 +537,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -569,6 +585,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -611,6 +628,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-1",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -640,6 +658,7 @@ func TestReconcile(t *testing.T) {
 				GitHub: &appv1.GitHub{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-1",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -650,6 +669,71 @@ func TestReconcile(t *testing.T) {
 	g.Expect(err).NotTo(gomega.HaveOccurred())
 
 	time.Sleep(2 * time.Second)
+
+	t.Log("helmrepo keep test")
+
+	helmReleaseName = "example-helmrepo-keep"
+	helmReleaseKey = types.NamespacedName{
+		Name:      helmReleaseName,
+		Namespace: helmReleaseNS,
+	}
+	instance = &appv1.HelmRelease{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "HelmRelease",
+			APIVersion: "apps.open-cluster-management.io/v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      helmReleaseName,
+			Namespace: helmReleaseNS,
+		},
+		Repo: appv1.HelmReleaseRepo{
+			Source: &appv1.Source{
+				SourceType: appv1.HelmRepoSourceType,
+				HelmRepo: &appv1.HelmRepo{
+					Urls: []string{
+						"https://raw.githubusercontent.com/stolostron/multicloud-operators-subscription-release/main/test/helmrepo/nginx-ingress-1.40.0_keep.tgz"},
+				},
+			},
+			ChartName: "nginx-ingress",
+		},
+	}
+
+	err = c.Create(context.TODO(), instance)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	time.Sleep(4 * time.Second)
+
+	instanceResp = &appv1.HelmRelease{}
+	err = c.Get(context.TODO(), helmReleaseKey, instanceResp)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	time.Sleep(4 * time.Second)
+
+	clusterRoleKey := types.NamespacedName{
+		Name: helmReleaseName + "-" + "nginx-ingress",
+	}
+	roleKey := types.NamespacedName{
+		Name:      helmReleaseName + "-" + "nginx-ingress",
+		Namespace: helmReleaseNS,
+	}
+	clusterRole := &v1.ClusterRole{}
+	err = c.Get(context.TODO(), clusterRoleKey, clusterRole)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	role := &v1.Role{}
+	err = c.Get(context.TODO(), roleKey, role)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	err = c.Delete(context.TODO(), instanceResp)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	time.Sleep(4 * time.Second)
+
+	err = c.Get(context.TODO(), clusterRoleKey, clusterRole)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
+
+	err = c.Get(context.TODO(), roleKey, role)
+	g.Expect(err).NotTo(gomega.HaveOccurred())
 }
 
 func Test_generateResourceListForGit(t *testing.T) {
@@ -691,6 +775,7 @@ func Test_generateResourceListForGit(t *testing.T) {
 				Git: &appv1.Git{
 					Urls:      []string{"https://github.com/stolostron/multicloud-operators-subscription-release.git"},
 					ChartPath: "test/github/subscription-release-test-3",
+					Branch:    "main",
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -740,7 +825,7 @@ func Test_generateResourceListForHelm(t *testing.T) {
 				SourceType: appv1.HelmRepoSourceType,
 				HelmRepo: &appv1.HelmRepo{
 					Urls: []string{
-						"https://raw.github.com/stolostron/multicloud-operators-subscription-release/master/test/helmrepo/subscription-release-test-3-0.1.0.tgz"},
+						"https://raw.github.com/stolostron/multicloud-operators-subscription-release/main/test/helmrepo/subscription-release-test-3-0.1.0.tgz"},
 				},
 			},
 			ChartName: "subscription-release-test-1",
@@ -751,97 +836,3 @@ func Test_generateResourceListForHelm(t *testing.T) {
 	g.Expect(err).NotTo(gomega.HaveOccurred())
 	g.Expect(resourceList).NotTo(gomega.BeNil())
 }
-
-func TestDeleteKeepCleanup(t *testing.T) {
-	defer klog.Flush()
-
-	g := gomega.NewGomegaWithT(t)
-
-	// Setup the Manager and Controller.  Wrap the Controller Reconcile function so it writes each request to a
-	// channel when it is finished.
-
-	t.Log("Create manager")
-
-	mgr, err := manager.New(cfg, manager.Options{
-		MetricsBindAddress: "0",
-		LeaderElection:     false,
-	})
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	c := mgr.GetClient()
-
-	t.Log("Setup test reconcile")
-	g.Expect(Add(mgr)).NotTo(gomega.HaveOccurred())
-
-	stopMgr, mgrStopped := StartTestManager(mgr, g)
-
-	defer func() {
-		close(stopMgr)
-		mgrStopped.Wait()
-	}()
-
-	t.Log("helmrepo keep test")
-
-	helmReleaseName := "example-helmrepo-keep"
-	helmReleaseKey := types.NamespacedName{
-		Name:      helmReleaseName,
-		Namespace: helmReleaseNS,
-	}
-	instance := &appv1.HelmRelease{
-		TypeMeta: metav1.TypeMeta{
-			Kind:       "HelmRelease",
-			APIVersion: "apps.open-cluster-management.io/v1",
-		},
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      helmReleaseName,
-			Namespace: helmReleaseNS,
-		},
-		Repo: appv1.HelmReleaseRepo{
-			Source: &appv1.Source{
-				SourceType: appv1.HelmRepoSourceType,
-				HelmRepo: &appv1.HelmRepo{
-					Urls: []string{
-						"https://raw.githubusercontent.com/stolostron/multicloud-operators-subscription-release/master/test/helmrepo/nginx-ingress-1.40.0_keep.tgz"},
-				},
-			},
-			ChartName: "nginx-ingress",
-		},
-	}
-
-	err = c.Create(context.TODO(), instance)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	time.Sleep(4 * time.Second)
-
-	instanceResp := &appv1.HelmRelease{}
-	err = c.Get(context.TODO(), helmReleaseKey, instanceResp)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	time.Sleep(4 * time.Second)
-
-	clusterRoleKey := types.NamespacedName{
-		Name: helmReleaseName + "-" + "nginx-ingress",
-	}
-	roleKey := types.NamespacedName{
-		Name:      helmReleaseName + "-" + "nginx-ingress",
-		Namespace: helmReleaseNS,
-	}
-	clusterRole := &v1.ClusterRole{}
-	err = c.Get(context.TODO(), clusterRoleKey, clusterRole)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	role := &v1.Role{}
-	err = c.Get(context.TODO(), roleKey, role)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	err = c.Delete(context.TODO(), instanceResp)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	time.Sleep(4 * time.Second)
-
-	err = c.Get(context.TODO(), clusterRoleKey, clusterRole)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-
-	err = c.Get(context.TODO(), roleKey, role)
-	g.Expect(err).NotTo(gomega.HaveOccurred())
-}
